@@ -5,23 +5,24 @@ use strict;
 use Graphics::Framebuffer;
 use Time::HiRes qw(sleep);
 
-my $joined = join('',@ARGV);
+my $joined = join('', @ARGV);
 my $wait = .75;
 $wait = $joined =~ /(\d++)/ if (scalar(@ARGV));
 my $dump = 0;
 $dump = 1 if ($joined =~ /dump/i);
 $wait = 0 if ($joined =~ /wait/i);
 
-my $fb = Graphics::Framebuffer->new('SPLASH' => 1,'SHOW_ERRORS'=>1); # ,'SIMULATED_X'=>1280,'SIMULATED_Y'=>720);
+my $fb = Graphics::Framebuffer->new('SPLASH' => 1, 'SHOW_ERRORS' => 1);    # ,'SIMULATED_X'=>1280,'SIMULATED_Y'=>720);
 
 $SIG{'INT'} = sub { $fb->cls('ON'); exit(0); };
 
 my $adj = $fb->{'XRES'} / 1920;
 
 $fb->cls('OFF');
+
 # $fb->or_mode();
 
-foreach my $font (sort(keys %{$fb->{'FONTS'}})) {
+foreach my $font (sort(keys %{ $fb->{'FONTS'} })) {
     unless ($dump) {
         $fb->cls();
         my $tprint = {
@@ -42,12 +43,8 @@ foreach my $font (sort(keys %{$fb->{'FONTS'}})) {
             'y'            => 76 * $adj,
             'antialias'    => 1
         };
-        $fb->ttf_print(
-            $fb->ttf_print($tprint)
-        );
-        $fb->ttf_print(
-            $fb->ttf_print($smprint)
-        );
+        $fb->ttf_print($fb->ttf_print($tprint));
+        $fb->ttf_print($fb->ttf_print($smprint));
         if ($wait) {
             sleep $wait;
         } else {
@@ -56,7 +53,7 @@ foreach my $font (sort(keys %{$fb->{'FONTS'}})) {
     } else {
         print STDOUT "$font\n";
     }
-}
+} ## end foreach my $font (sort(keys...))
 
 $fb->cls('ON');
 
